/**
 * This file is a part of LuminanceHDR package.
 * ----------------------------------------------------------------------
 * Copyright (C) 2006,2007,2008 Giuseppe Rota
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * ----------------------------------------------------------------------
 *
 * @author Daniel Kaneider <danielkaneider@users.sourceforge.net>
 *
 */

#ifndef MSVC_MATH_H
#define MSVC_MATH_H

//#define _USE_MATH_DEFINES
#include <math.h>  // re-include here

#include <boost/math/constants/constants.hpp>

#define exp2f(x) (powf(2.0f, x))
#define log2(x) (log(x) / std::math::double_constants::ln_two)
#define log2f(x) (logf(x) / std::math::double_constants::ln_two)

#pragma warning(disable : 4996)

#endif  // MSVC_MATH_H
